@@ -1,4 +1,4 @@
 # Pressing Alt+H will focus the entry
-entry <- gtkEntry();
+entry <- gtkEntry()
 label <- gtkLabelNewWithMnemonic("_Hello")
 label$setMnemonicWidget(entry)
